<template>
  <AnalyticsCard
    :is-loading="isLoading"
    :title="title"
  >
    <div class="mt-3 h-[22rem] w-full overflow-y-auto px-4 pb-4">
      <div class="grid grid-cols-1 gap-1.5">
        <template
          v-for="(referrer, index) in data"
          :key="index"
        >
          <div class="flex items-center justify-between">
            <div class="grow truncate text-sm text-gray-700">
              <template v-if="isEmpty(referrer.label)">
                {{ $t("app.links.analytics.referrers.direct") }}
              </template>
              <template v-else>
                <a
                  :href="referrer.label"
                  class="text-primary-700 hover:underline"
                  rel="noreferrer"
                  target="_blank"
                >
                  {{ referrer.label }}
                </a>
              </template>
            </div>
            <div class="ml-3 flex-none">
              <Badge>
                {{ referrer.value }}
              </Badge>
            </div>
          </div>
        </template>
      </div>
    </div>
  </AnalyticsCard>
</template>

<script lang="ts" setup>
import AnalyticsCard from "@/js/contexts/shared/ui/components/analytics/AnalyticsCard.vue";
import Badge from "@/js/contexts/shared/ui/components/badge/Badge.vue";
import { isEmpty } from "lodash-es";

defineProps<{
  isLoading: boolean;
  title: string;
  data: { label: string; value: number }[] | undefined;
}>();
</script>
